#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tidal
version:              1.9.5
visibility:           public
id:                   tidal-1.9.5-8HMkgSoqUxKKGXEfg3Xdxf
key:                  tidal-1.9.5-8HMkgSoqUxKKGXEfg3Xdxf
license:              GPL-3.0-only
copyright:            (c) Alex McLean and other contributors, 2021
maintainer:
    Alex McLean <alex@slab.org>, Mike Hodnick <mike.hodnick@gmail.com>

author:               Alex McLean
stability:            Experimental
homepage:             http://tidalcycles.org/
synopsis:             Pattern language for improvised music
description:
    Tidal is a domain specific language for live coding patterns.

category:             Sound
abi:                  22e1200161718314e6c032d0b1662375
exposed:              True
exposed-modules:
    Paths_tidal Sound.Tidal.Bjorklund Sound.Tidal.Chords
    Sound.Tidal.Config Sound.Tidal.Context Sound.Tidal.Control
    Sound.Tidal.Core Sound.Tidal.ID Sound.Tidal.Params
    Sound.Tidal.ParseBP Sound.Tidal.Pattern Sound.Tidal.Safe.Boot
    Sound.Tidal.Safe.Context Sound.Tidal.Scales Sound.Tidal.Show
    Sound.Tidal.Simple Sound.Tidal.Stream Sound.Tidal.StreamTypes
    Sound.Tidal.Tempo Sound.Tidal.Time Sound.Tidal.Transition
    Sound.Tidal.UI Sound.Tidal.Utils Sound.Tidal.Version

import-dirs:          /usr/lib/ghc-9.6.6/site-local/tidal-1.9.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/tidal-1.9.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/tidal-1.9.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tidal
hs-libraries:         HStidal-1.9.5-8HMkgSoqUxKKGXEfg3Xdxf
depends:
    base-4.18.2.1 bytestring-0.11.5.3
    clock-0.8.4-5EaxQTuUovXJFwGtpVLpFz
    colour-2.3.7-EKfA4aBVDkg4QWh8rS68yt containers-0.6.7
    deepseq-1.4.8.1 exceptions-0.10.7 hosc-0.20-BS28LTjUtgZ2wlSYOfEekM
    mtl-2.3.1 network-3.1.4.0-10rvNinchMB4AwxOArhT4I parsec-3.1.16.1
    primitive-0.9.1.0-CTO5MxhiVrsFEEvGOrOd6k
    random-1.2.1.3-Fpl3dUa1VuLH6jaWIu29Ly text-2.0.2
    tidal-link-1.0.3-BhLvLtes61CGmsoGsSKCkr transformers-0.6.1.0

haddock-interfaces:   /usr/share/doc/haskell-tidal/html/tidal.haddock
haddock-html:         /usr/share/doc/haskell-tidal/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

